#!/bin/bash


input_sparql_query_file=${1:-countries-in-esc-by-year.sparql}
output_ext=${2:-json}

output_file_root=${input_sparql_query_file%.*}

case "$output_ext" in
    "json" ) output_format="application/sparql-results+json"
    ;;

   "html" )  output_format="text/html"
    ;;

   "csv" )  output_format="text/csv"
    ;;
esac
	
output_result_file="$output_file_root.$output_ext"


source ./_lod_utils.bash

sparql_url="https://dbpedia.demo.openlinksw.com/sparql/"
#sparql_url="https://dbpedia.org/sparql"

graph_arg="default-graph-uri=http%3A%2F%2Fdbpedia.org"


sparql_query=`cat "$input_sparql_query_file"`
query_arg_safe="query="$( rawurlencode "$sparql_query" )

output_format_arg_safe="format="$( rawurlencode "$output_format" )

additional_args="$output_format_arg_safe&timeout=30000&signal_void=on&signal_unconnected=on"

tmp_table_filename="/tmp/table-sparql-result--$$.$output_ext"

#wget --no-check-certificate -O "table-$output_result_file" "$sparql_url?$graph_arg&$query_arg_safe&$additional_args"
wget --no-check-certificate -O "$tmp_table_filename" "$sparql_url?$graph_arg&$query_arg_safe&$additional_args"

cat html-table-header.html "$tmp_table_filename"  html-table-footer.html > "$output_result_file"

if [ $? = 0 ] ; then
    /bin/rm "$tmp_table_filename"
else
    echo "Failed to concatenate header+table+footer to create: $output_result_file" 1>&2
    echo "Leaving temporaryly generated table file for inspection: $tmp_table_filename" 1>&2
fi

